@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -20,8 +20,6 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 
-import org.drools.workbench.models.datamodel.oracle.DataType;
-import org.drools.workbench.models.datamodel.oracle.ModelField;
 import org.drools.workbench.models.guided.dtable.shared.model.ActionInsertFactCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.BRLActionColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.BRLActionVariableColumn;
@@ -29,15 +27,19 @@ import org.drools.workbench.models.guided.dtable.shared.model.BaseColumnFieldDif
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.IntegerUiColumn;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.LongUiColumn;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.StringUiColumn;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer.VetoException;
 import org.junit.Test;
+import org.kie.soup.project.datamodel.oracle.DataType;
+import org.kie.soup.project.datamodel.oracle.ModelField;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridCellValue;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
 import static org.drools.workbench.screens.guided.rule.client.util.ModelFieldUtil.modelField;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.verify;
 
 public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
 
@@ -70,7 +72,7 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testAppend1() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testAppend1() throws VetoException {
         //Single Column, single variable
         final BRLActionColumn column = new BRLActionColumn();
         final BRLActionVariableColumn columnV0 = new BRLActionVariableColumn("$age",
@@ -83,18 +85,18 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
 
         modelSynchronizer.appendColumn(column);
 
-        assertEquals(3,
+        assertEquals(4,
                      model.getExpandedColumns().size());
         assertEquals(1,
                      model.getActionCols().size());
 
-        assertEquals(3,
+        assertEquals(4,
                      uiModel.getColumns().size());
-        assertTrue(uiModel.getColumns().get(2) instanceof IntegerUiColumn);
+        assertTrue(uiModel.getColumns().get(3) instanceof IntegerUiColumn);
     }
 
     @Test
-    public void testAppend2() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testAppend2() throws VetoException {
         //Single Column, multiple variables
         final BRLActionColumn column = new BRLActionColumn();
         final BRLActionVariableColumn columnV0 = new BRLActionVariableColumn("$age",
@@ -113,28 +115,28 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
 
         modelSynchronizer.appendColumn(column);
 
-        assertEquals(4,
+        assertEquals(5,
                      model.getExpandedColumns().size());
         assertEquals(1,
                      model.getActionCols().size());
 
-        assertEquals(4,
+        assertEquals(5,
                      uiModel.getColumns().size());
-        assertTrue(uiModel.getColumns().get(2) instanceof IntegerUiColumn);
-        assertTrue(uiModel.getColumns().get(3) instanceof StringUiColumn);
+        assertTrue(uiModel.getColumns().get(3) instanceof IntegerUiColumn);
+        assertTrue(uiModel.getColumns().get(4) instanceof StringUiColumn);
 
         assertEquals("col1v0",
-                     uiModel.getColumns().get(2).getHeaderMetaData().get(0).getTitle());
-        assertEquals("$age",
-                     uiModel.getColumns().get(2).getHeaderMetaData().get(1).getTitle());
-        assertEquals("col1v1",
                      uiModel.getColumns().get(3).getHeaderMetaData().get(0).getTitle());
-        assertEquals("$name",
+        assertEquals("$age",
                      uiModel.getColumns().get(3).getHeaderMetaData().get(1).getTitle());
+        assertEquals("col1v1",
+                     uiModel.getColumns().get(4).getHeaderMetaData().get(0).getTitle());
+        assertEquals("$name",
+                     uiModel.getColumns().get(4).getHeaderMetaData().get(1).getTitle());
     }
 
     @Test
-    public void testUpdate1() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testUpdate1() throws VetoException {
         //Single Column, single variable
         final BRLActionColumn column = spy(new BRLActionColumn());
         final BRLActionVariableColumn columnV0 = new BRLActionVariableColumn("$age",
@@ -147,14 +149,14 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
 
         modelSynchronizer.appendColumn(column);
 
-        assertEquals(3,
+        assertEquals(4,
                      model.getExpandedColumns().size());
         assertEquals(1,
                      model.getActionCols().size());
 
-        assertEquals(3,
+        assertEquals(4,
                      uiModel.getColumns().size());
-        assertTrue(uiModel.getColumns().get(2) instanceof IntegerUiColumn);
+        assertTrue(uiModel.getColumns().get(3) instanceof IntegerUiColumn);
 
         final BRLActionColumn edited = new BRLActionColumn();
         final BRLActionVariableColumn editedColumnV0 = new BRLActionVariableColumn("$name",
@@ -173,24 +175,24 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
                      diffs.size());
         verify(column).diff(edited);
 
-        assertEquals(3,
+        assertEquals(4,
                      model.getExpandedColumns().size());
         assertEquals(1,
                      model.getActionCols().size());
 
-        assertEquals(3,
+        assertEquals(4,
                      uiModel.getColumns().size());
-        assertTrue(uiModel.getColumns().get(2) instanceof StringUiColumn);
+        assertTrue(uiModel.getColumns().get(3) instanceof StringUiColumn);
         assertEquals("updated",
-                     uiModel.getColumns().get(2).getHeaderMetaData().get(0).getTitle());
+                     uiModel.getColumns().get(3).getHeaderMetaData().get(0).getTitle());
         assertEquals("$name",
-                     uiModel.getColumns().get(2).getHeaderMetaData().get(1).getTitle());
+                     uiModel.getColumns().get(3).getHeaderMetaData().get(1).getTitle());
         assertEquals(false,
-                     uiModel.getColumns().get(2).isVisible());
+                     uiModel.getColumns().get(3).isVisible());
     }
 
     @Test
-    public void testUpdate2() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testUpdate2() throws VetoException {
         //Single Column, multiple variables
         final BRLActionColumn column = spy(new BRLActionColumn());
         final BRLActionVariableColumn columnV0 = new BRLActionVariableColumn("$age",
@@ -209,15 +211,15 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
 
         modelSynchronizer.appendColumn(column);
 
-        assertEquals(4,
+        assertEquals(5,
                      model.getExpandedColumns().size());
         assertEquals(1,
                      model.getActionCols().size());
 
-        assertEquals(4,
+        assertEquals(5,
                      uiModel.getColumns().size());
-        assertTrue(uiModel.getColumns().get(2) instanceof IntegerUiColumn);
-        assertTrue(uiModel.getColumns().get(3) instanceof StringUiColumn);
+        assertTrue(uiModel.getColumns().get(3) instanceof IntegerUiColumn);
+        assertTrue(uiModel.getColumns().get(4) instanceof StringUiColumn);
 
         final BRLActionColumn edited = new BRLActionColumn();
         final BRLActionVariableColumn editedColumnV0 = new BRLActionVariableColumn("$name",
@@ -236,24 +238,24 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
                      diffs.size());
         verify(column).diff(edited);
 
-        assertEquals(3,
+        assertEquals(4,
                      model.getExpandedColumns().size());
         assertEquals(1,
                      model.getActionCols().size());
 
-        assertEquals(3,
+        assertEquals(4,
                      uiModel.getColumns().size());
-        assertTrue(uiModel.getColumns().get(2) instanceof StringUiColumn);
+        assertTrue(uiModel.getColumns().get(3) instanceof StringUiColumn);
         assertEquals("updated",
-                     uiModel.getColumns().get(2).getHeaderMetaData().get(0).getTitle());
+                     uiModel.getColumns().get(3).getHeaderMetaData().get(0).getTitle());
         assertEquals("$name",
-                     uiModel.getColumns().get(2).getHeaderMetaData().get(1).getTitle());
+                     uiModel.getColumns().get(3).getHeaderMetaData().get(1).getTitle());
         assertEquals(false,
-                     uiModel.getColumns().get(2).isVisible());
+                     uiModel.getColumns().get(3).isVisible());
     }
 
     @Test
-    public void testUpdate3() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testUpdate3() throws VetoException {
         //Single Column, multiple variables
         final BRLActionColumn column = spy(new BRLActionColumn());
         final BRLActionVariableColumn columnV0 = new BRLActionVariableColumn("$age",
@@ -272,15 +274,15 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
 
         modelSynchronizer.appendColumn(column);
 
-        assertEquals(4,
+        assertEquals(5,
                      model.getExpandedColumns().size());
         assertEquals(1,
                      model.getActionCols().size());
 
-        assertEquals(4,
+        assertEquals(5,
                      uiModel.getColumns().size());
-        assertTrue(uiModel.getColumns().get(2) instanceof IntegerUiColumn);
-        assertTrue(uiModel.getColumns().get(3) instanceof StringUiColumn);
+        assertTrue(uiModel.getColumns().get(3) instanceof IntegerUiColumn);
+        assertTrue(uiModel.getColumns().get(4) instanceof StringUiColumn);
 
         final BRLActionColumn edited = new BRLActionColumn();
         final BRLActionVariableColumn editedColumnV0 = new BRLActionVariableColumn("$s",
@@ -299,24 +301,24 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
                      diffs.size());
         verify(column).diff(edited);
 
-        assertEquals(3,
+        assertEquals(4,
                      model.getExpandedColumns().size());
         assertEquals(1,
                      model.getActionCols().size());
 
-        assertEquals(3,
+        assertEquals(4,
                      uiModel.getColumns().size());
-        assertTrue(uiModel.getColumns().get(2) instanceof LongUiColumn);
+        assertTrue(uiModel.getColumns().get(3) instanceof LongUiColumn);
         assertEquals("updated",
-                     uiModel.getColumns().get(2).getHeaderMetaData().get(0).getTitle());
+                     uiModel.getColumns().get(3).getHeaderMetaData().get(0).getTitle());
         assertEquals("$s",
-                     uiModel.getColumns().get(2).getHeaderMetaData().get(1).getTitle());
+                     uiModel.getColumns().get(3).getHeaderMetaData().get(1).getTitle());
         assertEquals(false,
-                     uiModel.getColumns().get(2).isVisible());
+                     uiModel.getColumns().get(3).isVisible());
     }
 
     @Test
-    public void testDelete() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testDelete() throws VetoException {
         final BRLActionColumn column = new BRLActionColumn();
         final BRLActionVariableColumn columnV0 = new BRLActionVariableColumn("$age",
                                                                              DataType.TYPE_NUMERIC_INTEGER,
@@ -334,27 +336,27 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
 
         modelSynchronizer.appendColumn(column);
 
-        assertEquals(4,
+        assertEquals(5,
                      model.getExpandedColumns().size());
         assertEquals(1,
                      model.getActionCols().size());
 
-        assertEquals(4,
+        assertEquals(5,
                      uiModel.getColumns().size());
 
         modelSynchronizer.deleteColumn(column);
 
-        assertEquals(2,
+        assertEquals(3,
                      model.getExpandedColumns().size());
         assertEquals(0,
                      model.getActionCols().size());
 
-        assertEquals(2,
+        assertEquals(3,
                      uiModel.getColumns().size());
     }
 
     @Test
-    public void testMoveBRLActionVariableColumnTo() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveBRLActionVariableColumnTo() throws VetoException {
         final BRLActionColumn column1 = new BRLActionColumn();
         final BRLActionVariableColumn column1v0 = new BRLActionVariableColumn("$age",
                                                                               DataType.TYPE_NUMERIC_INTEGER,
@@ -382,15 +384,15 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        2,
-                        new BaseGridCellValue<Integer>(55));
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<String>("Smurf"));
-        uiModel.setCell(0,
-                        4,
-                        new BaseGridCellValue<String>("Canada"));
+        uiModel.setCellValue(0,
+                             3,
+                             new BaseGridCellValue<Integer>(55));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<String>("Smurf"));
+        uiModel.setCellValue(0,
+                             5,
+                             new BaseGridCellValue<String>("Canada"));
 
         assertEquals(2,
                      model.getActionCols().size());
@@ -399,17 +401,17 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column2,
                      model.getActionCols().get(1));
         assertEquals(55,
-                     model.getData().get(0).get(2).getNumericValue());
+                     model.getData().get(0).get(3).getNumericValue());
         assertEquals("Smurf",
-                     model.getData().get(0).get(3).getStringValue());
-        assertEquals("Canada",
                      model.getData().get(0).get(4).getStringValue());
+        assertEquals("Canada",
+                     model.getData().get(0).get(5).getStringValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn3_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn3_1 = uiModel.getColumns().get(5);
         assertEquals("age",
                      uiModelColumn1_1.getHeaderMetaData().get(0).getTitle());
         assertEquals("name",
@@ -417,11 +419,11 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertTrue(uiModelColumn1_1 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn2_1 instanceof StringUiColumn);
         assertTrue(uiModelColumn3_1 instanceof StringUiColumn);
-        assertEquals(2,
-                     uiModelColumn1_1.getIndex());
         assertEquals(3,
-                     uiModelColumn2_1.getIndex());
+                     uiModelColumn1_1.getIndex());
         assertEquals(4,
+                     uiModelColumn2_1.getIndex());
+        assertEquals(5,
                      uiModelColumn3_1.getIndex());
         assertEquals(55,
                      uiModel.getRow(0).getCells().get(uiModelColumn1_1.getIndex()).getValue().getValue());
@@ -430,7 +432,7 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals("Canada",
                      uiModel.getRow(0).getCells().get(uiModelColumn3_1.getIndex()).getValue().getValue());
 
-        uiModel.moveColumnTo(2,
+        uiModel.moveColumnTo(3,
                              uiModelColumn2_1);
 
         //The move should have been vetoed and nothing changed
@@ -441,17 +443,17 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column2,
                      model.getActionCols().get(1));
         assertEquals(55,
-                     model.getData().get(0).get(2).getNumericValue());
+                     model.getData().get(0).get(3).getNumericValue());
         assertEquals("Smurf",
-                     model.getData().get(0).get(3).getStringValue());
-        assertEquals("Canada",
                      model.getData().get(0).get(4).getStringValue());
+        assertEquals("Canada",
+                     model.getData().get(0).get(5).getStringValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn3_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn3_2 = uiModel.getColumns().get(5);
         assertEquals("age",
                      uiModelColumn1_2.getHeaderMetaData().get(0).getTitle());
         assertEquals("name",
@@ -459,11 +461,11 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertTrue(uiModelColumn1_2 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn2_2 instanceof StringUiColumn);
         assertTrue(uiModelColumn3_2 instanceof StringUiColumn);
-        assertEquals(2,
-                     uiModelColumn1_2.getIndex());
         assertEquals(3,
-                     uiModelColumn2_2.getIndex());
+                     uiModelColumn1_2.getIndex());
         assertEquals(4,
+                     uiModelColumn2_2.getIndex());
+        assertEquals(5,
                      uiModelColumn3_2.getIndex());
         assertEquals(55,
                      uiModel.getRow(0).getCells().get(uiModelColumn1_2.getIndex()).getValue().getValue());
@@ -474,7 +476,7 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testMoveBRLActionBlockTo() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveBRLActionBlockTo() throws VetoException {
         final BRLActionColumn column1 = new BRLActionColumn();
         final BRLActionVariableColumn column1v0 = new BRLActionVariableColumn("$age",
                                                                               DataType.TYPE_NUMERIC_INTEGER,
@@ -500,15 +502,15 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        2,
-                        new BaseGridCellValue<>(55));
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<>("Smurf"));
-        uiModel.setCell(0,
-                        4,
-                        new BaseGridCellValue<>("Canada"));
+        uiModel.setCellValue(0,
+                             3,
+                             new BaseGridCellValue<>(55));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<>("Smurf"));
+        uiModel.setCellValue(0,
+                             5,
+                             new BaseGridCellValue<>("Canada"));
 
         assertEquals(2,
                      model.getActionCols().size());
@@ -517,17 +519,17 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column2,
                      model.getActionCols().get(1));
         assertEquals(55,
-                     model.getData().get(0).get(2).getNumericValue());
+                     model.getData().get(0).get(3).getNumericValue());
         assertEquals("Smurf",
-                     model.getData().get(0).get(3).getStringValue());
-        assertEquals("Canada",
                      model.getData().get(0).get(4).getStringValue());
+        assertEquals("Canada",
+                     model.getData().get(0).get(5).getStringValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn3_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn3_1 = uiModel.getColumns().get(5);
         assertEquals("age",
                      uiModelColumn1_1.getHeaderMetaData().get(0).getTitle());
         assertEquals("name",
@@ -535,11 +537,11 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertTrue(uiModelColumn1_1 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn2_1 instanceof StringUiColumn);
         assertTrue(uiModelColumn3_1 instanceof StringUiColumn);
-        assertEquals(2,
-                     uiModelColumn1_1.getIndex());
         assertEquals(3,
-                     uiModelColumn2_1.getIndex());
+                     uiModelColumn1_1.getIndex());
         assertEquals(4,
+                     uiModelColumn2_1.getIndex());
+        assertEquals(5,
                      uiModelColumn3_1.getIndex());
         assertEquals(55,
                      uiModel.getRow(0).getCells().get(uiModelColumn1_1.getIndex()).getValue().getValue());
@@ -548,7 +550,7 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals("Canada",
                      uiModel.getRow(0).getCells().get(uiModelColumn3_1.getIndex()).getValue().getValue());
 
-        uiModel.moveColumnsTo(4,
+        uiModel.moveColumnsTo(5,
                               new ArrayList<GridColumn<?>>() {{
                                   add(uiModelColumn1_1);
                                   add(uiModelColumn2_1);
@@ -561,17 +563,17 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column1,
                      model.getActionCols().get(1));
         assertEquals("Canada",
-                     model.getData().get(0).get(2).getStringValue());
+                     model.getData().get(0).get(3).getStringValue());
         assertEquals(55,
-                     model.getData().get(0).get(3).getNumericValue());
+                     model.getData().get(0).get(4).getNumericValue());
         assertEquals("Smurf",
-                     model.getData().get(0).get(4).getStringValue());
+                     model.getData().get(0).get(5).getStringValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn3_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn3_2 = uiModel.getColumns().get(5);
         assertEquals("$a : Address",
                      uiModelColumn1_2.getHeaderMetaData().get(0).getTitle());
         assertEquals("age",
@@ -581,11 +583,11 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertTrue(uiModelColumn1_2 instanceof StringUiColumn);
         assertTrue(uiModelColumn2_2 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn3_2 instanceof StringUiColumn);
-        assertEquals(4,
+        assertEquals(5,
                      uiModelColumn1_2.getIndex());
-        assertEquals(2,
-                     uiModelColumn2_2.getIndex());
         assertEquals(3,
+                     uiModelColumn2_2.getIndex());
+        assertEquals(4,
                      uiModelColumn3_2.getIndex());
         assertEquals("Canada",
                      uiModel.getRow(0).getCells().get(uiModelColumn1_2.getIndex()).getValue().getValue());
@@ -596,7 +598,7 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testMoveActionBefore() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveActionBefore() throws VetoException {
         final BRLActionColumn column1 = new BRLActionColumn();
         final BRLActionVariableColumn column1v0 = new BRLActionVariableColumn("$age",
                                                                               DataType.TYPE_NUMERIC_INTEGER,
@@ -622,15 +624,15 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        2,
-                        new BaseGridCellValue<>(55));
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<>("Smurf"));
-        uiModel.setCell(0,
-                        4,
-                        new BaseGridCellValue<>("Canada"));
+        uiModel.setCellValue(0,
+                             3,
+                             new BaseGridCellValue<>(55));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<>("Smurf"));
+        uiModel.setCellValue(0,
+                             5,
+                             new BaseGridCellValue<>("Canada"));
 
         assertEquals(2,
                      model.getActionCols().size());
@@ -639,17 +641,17 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column2,
                      model.getActionCols().get(1));
         assertEquals(55,
-                     model.getData().get(0).get(2).getNumericValue());
+                     model.getData().get(0).get(3).getNumericValue());
         assertEquals("Smurf",
-                     model.getData().get(0).get(3).getStringValue());
-        assertEquals("Canada",
                      model.getData().get(0).get(4).getStringValue());
+        assertEquals("Canada",
+                     model.getData().get(0).get(5).getStringValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn3_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn3_1 = uiModel.getColumns().get(5);
         assertEquals("age",
                      uiModelColumn1_1.getHeaderMetaData().get(0).getTitle());
         assertEquals("name",
@@ -657,11 +659,11 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertTrue(uiModelColumn1_1 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn2_1 instanceof StringUiColumn);
         assertTrue(uiModelColumn3_1 instanceof StringUiColumn);
-        assertEquals(2,
-                     uiModelColumn1_1.getIndex());
         assertEquals(3,
-                     uiModelColumn2_1.getIndex());
+                     uiModelColumn1_1.getIndex());
         assertEquals(4,
+                     uiModelColumn2_1.getIndex());
+        assertEquals(5,
                      uiModelColumn3_1.getIndex());
         assertEquals(55,
                      uiModel.getRow(0).getCells().get(uiModelColumn1_1.getIndex()).getValue().getValue());
@@ -670,7 +672,7 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals("Canada",
                      uiModel.getRow(0).getCells().get(uiModelColumn3_1.getIndex()).getValue().getValue());
 
-        uiModel.moveColumnTo(2,
+        uiModel.moveColumnTo(3,
                              uiModelColumn3_1);
 
         assertEquals(2,
@@ -680,17 +682,17 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column1,
                      model.getActionCols().get(1));
         assertEquals("Canada",
-                     model.getData().get(0).get(2).getStringValue());
+                     model.getData().get(0).get(3).getStringValue());
         assertEquals(55,
-                     model.getData().get(0).get(3).getNumericValue());
+                     model.getData().get(0).get(4).getNumericValue());
         assertEquals("Smurf",
-                     model.getData().get(0).get(4).getStringValue());
+                     model.getData().get(0).get(5).getStringValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn3_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn3_2 = uiModel.getColumns().get(5);
         assertEquals("$a : Address",
                      uiModelColumn1_2.getHeaderMetaData().get(0).getTitle());
         assertEquals("age",
@@ -700,11 +702,11 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertTrue(uiModelColumn1_2 instanceof StringUiColumn);
         assertTrue(uiModelColumn2_2 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn3_2 instanceof StringUiColumn);
-        assertEquals(4,
+        assertEquals(5,
                      uiModelColumn1_2.getIndex());
-        assertEquals(2,
-                     uiModelColumn2_2.getIndex());
         assertEquals(3,
+                     uiModelColumn2_2.getIndex());
+        assertEquals(4,
                      uiModelColumn3_2.getIndex());
         assertEquals("Canada",
                      uiModel.getRow(0).getCells().get(uiModelColumn1_2.getIndex()).getValue().getValue());
@@ -715,7 +717,7 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testMoveActionAfter() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveActionAfter() throws VetoException {
         final ActionInsertFactCol52 column1 = new ActionInsertFactCol52();
         column1.setHeader("country");
         column1.setBoundName("$a");
@@ -741,15 +743,15 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        2,
-                        new BaseGridCellValue<>("Canada"));
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<>(55));
-        uiModel.setCell(0,
-                        4,
-                        new BaseGridCellValue<>("Smurf"));
+        uiModel.setCellValue(0,
+                             3,
+                             new BaseGridCellValue<>("Canada"));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<>(55));
+        uiModel.setCellValue(0,
+                             5,
+                             new BaseGridCellValue<>("Smurf"));
 
         assertEquals(2,
                      model.getActionCols().size());
@@ -758,17 +760,17 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column2,
                      model.getActionCols().get(1));
         assertEquals("Canada",
-                     model.getData().get(0).get(2).getStringValue());
+                     model.getData().get(0).get(3).getStringValue());
         assertEquals(55,
-                     model.getData().get(0).get(3).getNumericValue());
+                     model.getData().get(0).get(4).getNumericValue());
         assertEquals("Smurf",
-                     model.getData().get(0).get(4).getStringValue());
+                     model.getData().get(0).get(5).getStringValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn3_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn3_1 = uiModel.getColumns().get(5);
         assertEquals("age",
                      uiModelColumn2_1.getHeaderMetaData().get(0).getTitle());
         assertEquals("name",
@@ -776,11 +778,11 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertTrue(uiModelColumn1_1 instanceof StringUiColumn);
         assertTrue(uiModelColumn2_1 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn3_1 instanceof StringUiColumn);
-        assertEquals(2,
-                     uiModelColumn1_1.getIndex());
         assertEquals(3,
-                     uiModelColumn2_1.getIndex());
+                     uiModelColumn1_1.getIndex());
         assertEquals(4,
+                     uiModelColumn2_1.getIndex());
+        assertEquals(5,
                      uiModelColumn3_1.getIndex());
         assertEquals("Canada",
                      uiModel.getRow(0).getCells().get(uiModelColumn1_1.getIndex()).getValue().getValue());
@@ -789,7 +791,7 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals("Smurf",
                      uiModel.getRow(0).getCells().get(uiModelColumn3_1.getIndex()).getValue().getValue());
 
-        uiModel.moveColumnTo(4,
+        uiModel.moveColumnTo(5,
                              uiModelColumn1_1);
 
         assertEquals(2,
@@ -799,17 +801,17 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column1,
                      model.getActionCols().get(1));
         assertEquals(55,
-                     model.getData().get(0).get(2).getNumericValue());
+                     model.getData().get(0).get(3).getNumericValue());
         assertEquals("Smurf",
-                     model.getData().get(0).get(3).getStringValue());
-        assertEquals("Canada",
                      model.getData().get(0).get(4).getStringValue());
+        assertEquals("Canada",
+                     model.getData().get(0).get(5).getStringValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn3_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn3_2 = uiModel.getColumns().get(5);
         assertEquals("age",
                      uiModelColumn1_2.getHeaderMetaData().get(0).getTitle());
         assertEquals("name",
@@ -819,11 +821,11 @@ public class BRLActionColumnSynchronizerTest extends BaseSynchronizerTest {
         assertTrue(uiModelColumn1_2 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn2_2 instanceof StringUiColumn);
         assertTrue(uiModelColumn3_2 instanceof StringUiColumn);
-        assertEquals(3,
-                     uiModelColumn1_2.getIndex());
         assertEquals(4,
+                     uiModelColumn1_2.getIndex());
+        assertEquals(5,
                      uiModelColumn2_2.getIndex());
-        assertEquals(2,
+        assertEquals(3,
                      uiModelColumn3_2.getIndex());
         assertEquals(55,
                      uiModel.getRow(0).getCells().get(uiModelColumn1_2.getIndex()).getValue().getValue());
