@@ -25,6 +25,7 @@ import com.google.gwt.user.client.ui.IsWidget;
 import org.drools.workbench.screens.scorecardxls.client.type.ScoreCardXLSResourceType;
 import org.drools.workbench.screens.scorecardxls.service.ScoreCardXLSContent;
 import org.drools.workbench.screens.scorecardxls.service.ScoreCardXLSService;
+import org.guvnor.common.services.shared.metadata.MetadataService;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
 import org.kie.workbench.common.widgets.client.popups.validation.ValidationPopup;
@@ -54,6 +55,9 @@ public class ScoreCardXLSEditorPresenter
     @Inject
     protected Caller<ScoreCardXLSService> scoreCardXLSService;
 
+    @Inject
+    protected Caller<MetadataService> metadataService;
+
     @Inject
     protected ValidationPopup validationPopup;
 
@@ -106,6 +110,14 @@ public class ScoreCardXLSEditorPresenter
                                                              versionRecordManager.getCurrentPath());
     }
 
+    @Override
+    protected void save(String commitMessage) {
+        metadataService.call(getSaveSuccessCallback(metadata.hashCode()))
+                .saveMetadata(versionRecordManager.getCurrentPath(),
+                              metadata,
+                              commitMessage);
+    }
+
     @Override
     protected String getEditorIdentifier() {
         return EDITOR_ID;
